# Tests

The tests for Haven and Firefly have been moved to src/haven/tests and
src/firefly/tests respectively.

The remaining test module, ``test_simulated_ioc.py``, is skipped, and
is here in case we want to start using the simulated IOCs again.